@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 
-from slackbot.bot import respond_to
+from oncall_slackbot.bot import respond_to
 
 
 @respond_to('^reply blocks$')
