@@ -1,13 +1,21 @@
+# -*- coding: utf-8 -*-
 
 import logging
-from oncall_slackbot.bot import nlp_label_listen_to, nlp_label_respond_to
-from oncall_slackbot.dispatcher import OnCallMessage
+from oncall_slackbot.bot import nlp_label_listen_to, nlp_label_respond_to, Message
 from oncall_slackbot.integrations.nlp import spacy
 
-
 LOGGER = logging.getLogger(__name__)
 
 
+class OnCallMessage(Message):
+    """
+    Overrides a message to add support for nlp label.
+    """
+    @property
+    def nlp_label(self):
+        return self._body.get('nlp_label')
+
+
 @nlp_label_listen_to(r'^test')
 def process_nlp(message: OnCallMessage):
     # You don't have to process the doc with spacy again, but you can if you want to retrieve more information
